# 安装
pip install GPminer


# GPstrat 主要模块
遗传算法策略挖掘框架

![image](https://github.com/user-attachments/assets/1eaa5124-3c13-4cdb-ac80-6d6cd683b0f7)


# hello world
demo文件夹，数据与自定义参数可修改

# -------------------- 联系作者 ---------------------
对于框架外需求或改进建议，可以联系作者。
![cde0c826807b3836377d0e13cf4bbf4](https://github.com/user-attachments/assets/3954cec9-8d4e-481c-a014-2ec971ab7cb4)

